|
| System.Console.Haskeline.Completion |
|
|
|
|
|
| Synopsis |
|
|
|
| Documentation |
|
|
| Performs completions from a reversed String.
The output String is also reversed.
Use completeWord to build these functions.
|
|
|
| Constructors | | Completion | | | replacement :: String | Text to insert in line.
| | display :: String | Text to display when listing
alternatives.
| | isFinished :: Bool | Whether this word should be followed by a
space, end quote, etc.
|
|
| Instances | |
|
|
|
|
|
|
|
|
| Building CompletionFuncs
|
|
|
| Disable completion altogether.
|
|
|
| Create a finished completion out of the given word.
|
|
| Filename completion
|
|
|
|
|
| List all of the files or folders beginning with this path.
|
|
|
|
| Produced by Haddock version 2.4.2 |